<?php
/**
 * Credit Card settings class
 *
 * @package WooAsaas
 */

namespace WC_Asaas\Admin\Settings;

/**
 * Credit Card settings
 */
class Credit_Card extends Settings {

	/**
	 *
	 * {@inheritDoc}
	 *
	 * @see \WC_Asaas\Admin\Settings\Settings::get_fields()
	 */
	public function get_fields() {
		$fields                           = parent::get_fields();
		$fields['description']['default'] = __( 'Pay your purchase with credit card.', 'woo-asaas' );

		// Create an array with the brands key as key and the name as value.
		$brands = $this->gateway->get_type()->brands();
		$brands = array_combine( array_keys( $brands ), array_column( $brands, 'name' ) );

		return apply_filters(
			'woocommerce_asaas_cc_settings_fields',
			array_merge(
				$fields,
				array(
					'min_total'             => array(
						'title'       => __( 'Order minimum total', 'woo-asaas' ),
						'type'        => 'text',
						'description' => __( 'The order minimum total to allow use this payment method. Use <code>0</code> to disable this option.', 'woo-asaas' ),
						'default'     => '0',
						'section'     => 'gateway',
						'priority'    => 10,
					),
					'max_installments'      => array(
						'title'       => __( 'Installments', 'woo-asaas' ),
						'type'        => 'text',
						/* translators: %d: maximum installments allowed  */
						'description' => sprintf( __( 'Define the installment limit allowed. The max value is <code>%d</code>. Use <code>0</code> to disable this option.', 'woo-asaas' ), $this->gateway->get_max_installments() ),
						'default'     => '0',
						'section'     => 'gateway',
						'priority'    => 20,
					),
					'min_installment_value' => array(
						'title'       => __( 'Minimum installment value', 'woo-asaas' ),
						'type'        => 'text',
						/* translators: %d: minimum installments value  */
						'description' => sprintf( __( 'The minimum value for each installment. The minimum value accepted by Asaas is <code>%s</code>.', 'woo-asaas' ), wc_price( $this->gateway->get_min_installment_value() ) ),
						'default'     => $this->gateway->get_min_installment_value(),
						'section'     => 'gateway',
						'priority'    => 30,
					),
					'brands_supported'      => array(
						'title'          => __( 'Brands', 'woo-asaas' ),
						'type'           => 'multiselect',
						'description'    => __( 'Choose the credit card brands that your store will accept.', 'woo-asaas' ),
						'options'        => $brands,
						'default'        => array_keys( $brands ),
						'select_buttons' => true,
						'class'          => 'wc-enhanced-select',
						'section'        => 'gateway',
						'priority'       => 40,
					),
					'one_click_buy'         => array(
						'title'       => __( 'One-Click Buy', 'woo-asaas' ),
						'type'        => 'checkbox',
						'label'       => __( 'Enable one-click buy', 'woo-asaas' ),
						'description' => __( 'To enable one-click buy please contact your Asaas manager.', 'woo-asaas' ),
						'default'     => 'no',
						'shared'      => true,
						'section'     => 'advanced',
						'priority'    => 10,
					),
				)
			),
			$this
		);
	}

	/**
	 *
	 * {@inheritDoc}
	 *
	 * @see \WC_Asaas\Admin\Settings\Settings::get_sections()
	 */
	public function get_sections() {
		$sections                     = parent::get_sections();
		$sections['gateway']['title'] = __( 'Credit Card', 'woo-asaas' );
		return apply_filters( 'woocommerce_asaas_cc_settings_sections', $sections );
	}
}
