<?php
/**
 * Credit card helper class
 *
 * @package WooAsaas
 */

namespace WC_Asaas\Helper;

use WC_Asaas\Gateway\Gateway;

/**
 * Credit card information helper functions
 */
class Credit_Card_Helper {

	/**
	 * Get credit card brand from the card number
	 *
	 * @param Gateway $gateway The gateway is being processed.
	 * @param string  $card_number The card number.
	 * @return array|boolean The brand definition. False, if the number doesn't match with any supported brand.
	 */
	public function get_card_brand( $gateway, $card_number ) {
		// cleanup spaces of card number.
		$card_number = preg_replace( '/\s+/', '', $card_number );

		$brands_supported = $gateway->get_option( 'brands_supported' );
		$brands           = $gateway->get_type()->brands();

		foreach ( $brands_supported as $brand ) {
			if ( preg_match( $brands[ $brand ]['number_validation'], $card_number ) ) {
				return $brands[ $brand ];
			}
		}

		return false;
	}

	/**
	 * Get all supported brands by the gateway
	 *
	 * @param Gateway $gateway The gateway is being processed.
	 * @return array The supported brands definition.
	 */
	public function supported_brands_name( $gateway ) {
		$brands_supported       = $gateway->get_option( 'brands_supported' );
		$brands                 = $gateway->get_type()->brands();
		$brands_supported_names = array();
		foreach ( $brands_supported as $brand ) {
			$brands_supported_names[] = $brands[ $brand ]['name'];
		}

		return $brands_supported_names;
	}
}
